===============================
Amadeus Python Library
===============================

.. image:: https://img.shields.io/travis/ardydedase/amadeus-python.svg
        :target: https://travis-ci.org/ardydedase/amadeus-python

.. image:: https://img.shields.io/pypi/v/amadeus.svg
        :target: https://pypi.python.org/pypi/amadeus

.. image:: https://readthedocs.org/projects/amadeus/badge/?version=latest
        :target: https://readthedocs.org/projects/amadeus/?badge=latest
        :alt: Documentation Status

Python Package for Amadeus Travel Innovation Sandbox

* Free software: BSD license
* Amadeus Travel Innovation Sandbox Documentation: https://sandbox.amadeus.com/apis
* Python Package Documentation: https://amadeus.readthedocs.org.

Features
--------

* :airplane:: **Flight Inspiration Search** allows you to answer the question: *Where can I go within a given travel budget?*
* :airplane:: **Extensive Flight Search** allows you to answer the question: *When is the best date to fly?*
* :airplane:: **Low-Fare Search** lets you find the cheapest one way or return itineraries.
* :hotel:: **Hotel Lowest Price Search** by center point/radius and by latitude/longitude window.
* :car:: **Car Rental Availability Search** by center point/radius and by airport.
* :train:: **Trains & Rail** supports Rail station auto-complete and information.
* :factory:: **CO2 Emissions Data** average per passenger by origin and destination.
* :white_check_mark:: Tested on Python 2.6, 2.7, 3.3 and 3.4 for this release.

Installation
------------

At the command line::

    $ pip install amadeus

Or::

    $ easy_install amadeus

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv amadeus
    $ pip install amadeus

Usage
-----

Read the docs! http://amadeus.readthedocs.org/en/latest/usage.html    
